'''$URL: svn+ssh://svn.mems-exchange.org/repos/trunk/toboso/lib/local_ui.py $
$Id: local_ui.py 23201 2003-11-20 16:41:46Z rmasse $
'''

from dulcinea.immutable_list import ImmutableList as _ImmutableList
from dulcinea.ui.user.login import setup_user_session
from toboso.ui.standard import header, footer

format_login_agreement = lambda : None # No login agreement

FEEDBACK_DOMAIN = 'yourdomain.here'

VALID_FEEDBACK_ADDRESSES = _ImmutableList(['boss'])
